==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/holidays/classes/Facade/HolidaysAllowance.php <==
<?php
namespace Claromentis\Holidays\Facade;

$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] ?: array()) + array("_6a365c6979e2bf9a9c86f" . "f80b519cee4" => base64_decode("Ly4uL2xlZ2FjeS" . "9IcEdyb3Vwcy5w" . "aHA="), "_a591754a8ddcdbda9c80f1db4d9" . "11e14" => base64_decode("aXNfb" . "nVsbA" . "=="), "_6b3d668392ab6a1" . "e7278b02b2d8cbf4" . "f" => base64_decode("K" . "w" . "=" . "="), "_3f02a0f67d82eb84435" . "7e916ed53cf74" => base64_decode("KzEgeWVhciAt" . "MSBkYXk="), "_483d8e1e03524f8bc" . "027dd8ef51c317b" => base64_decode("IG" . "Rh" . "eX" . "M="));
use Claromentis\Holidays\Repository\UserStatRepository;




class HolidaysAllowance
{
    protected $user_stat_repository;
    protected $user_zone;
    public function __construct(UserStatRepository $_61c138f2abc024469ef27c9ee68174c7, UserZone $_5fb9f14d9526956387db3d98f5eb1bad)
    {
        $this->user_stat_repository = $_61c138f2abc024469ef27c9ee68174c7;
        $this->user_zone = $_5fb9f14d9526956387db3d98f5eb1bad;
    }
    
    
    
    
    
    
    
    public function GetYearDates($user_id, $_3e373b62dabc05e536ff20103c34887e)
    {
        $_7873495be14ba37c2772c25d9dd55204 = $this->GetHolidayStartMonth($user_id);
        if ($GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_a591754a8ddcdbda9c80f1db4d" . "911e14"]($_7873495be14ba37c2772c25d9dd55204)) {
            $_7873495be14ba37c2772c25d9dd55204 = 1;
        }
        $_ccd9e402149a4aff4a20de187781aa41 = new \DateDay();
        $_ccd9e402149a4aff4a20de187781aa41->setDate($_3e373b62dabc05e536ff20103c34887e, $_7873495be14ba37c2772c25d9dd55204, 1);
        $_ef3a72fcbe857b2afe45cb9d8cafb253 = clone $_ccd9e402149a4aff4a20de187781aa41;
        $_ef3a72fcbe857b2afe45cb9d8cafb253->modify($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_3f02a0f6" . "7d82eb844" . "357e916ed" . "53cf74"]);
        return array($_ccd9e402149a4aff4a20de187781aa41, $_ef3a72fcbe857b2afe45cb9d8cafb253);
    }
    protected function GetHolidayStartMonth($user_id)
    {
        require_once __DIR__ . $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_6a365c6979e2" . "bf9a9c86ff80b" . "519cee4"];
        $_5438521fdece7fdb63944a7fc8541030 = $this->user_zone->GetUserZoneId($user_id);
        if (!$_5438521fdece7fdb63944a7fc8541030) {
            return null;
        }
        list(, , $_0626e9320d79e984f816b274072412ab) = \HPZoneElement::GetZoneConfig($_5438521fdece7fdb63944a7fc8541030);
        return $_0626e9320d79e984f816b274072412ab;
    }
    public function GetQuota($user_id, $_3e373b62dabc05e536ff20103c34887e)
    {
        return $this->user_stat_repository->GetQuota($user_id, $_3e373b62dabc05e536ff20103c34887e);
    }
    
    
    
    
    
    
    
    public function GetCarryRules($user_id, $_3e373b62dabc05e536ff20103c34887e)
    {
        require_once __DIR__ . $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_6a365c6979e2bf9a9c86ff80b519" . "cee4"];
        $_5438521fdece7fdb63944a7fc8541030 = $this->user_zone->GetUserZoneId($user_id);
        list($_0002ef7ca5f6fef6d624b8c14d22eed2, $_efde034d8ca9fc67f74c119ab0dd0f54) = \HPZoneElement::GetZoneConfig($_5438521fdece7fdb63944a7fc8541030);
        return array($_0002ef7ca5f6fef6d624b8c14d22eed2, $_efde034d8ca9fc67f74c119ab0dd0f54);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function GetCarriedExpirationDate($user_id, $_3e373b62dabc05e536ff20103c34887e)
    {
        list($_0002ef7ca5f6fef6d624b8c14d22eed2, $_efde034d8ca9fc67f74c119ab0dd0f54) = $this->GetCarryRules($user_id, $_3e373b62dabc05e536ff20103c34887e);
        if ($_0002ef7ca5f6fef6d624b8c14d22eed2 == 0 || $_efde034d8ca9fc67f74c119ab0dd0f54 == 0) {
            return null;
        }
        list($_0626e9320d79e984f816b274072412ab, ) = $this->GetYearDates($user_id, $_3e373b62dabc05e536ff20103c34887e);
        $_efde034d8ca9fc67f74c119ab0dd0f54++;
        $_0626e9320d79e984f816b274072412ab->modify($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_6b3d668392ab" . "6a1e7278b02b2" . "d8cbf4f"] . $_efde034d8ca9fc67f74c119ab0dd0f54 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_483d8e1e03524f8bc027dd8" . "ef51c317b"]);
        return $_0626e9320d79e984f816b274072412ab;
    }
    public function GetYearByDate($user_id, \DateDay $_67a0d624aebcceb0abd5ce56a53ff06f)
    {
        $_0626e9320d79e984f816b274072412ab = $this->GetHolidayStartMonth($user_id);
        if ($_0626e9320d79e984f816b274072412ab === null) {
            return $_67a0d624aebcceb0abd5ce56a53ff06f->getYear();
        }
        return $_67a0d624aebcceb0abd5ce56a53ff06f->getYear() - ($_67a0d624aebcceb0abd5ce56a53ff06f->getMonth() < $_0626e9320d79e984f816b274072412ab ? 1 : 0);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/holidays/classes/Facade/HolidaysAllowance.php <==
<?php
namespace Claromentis\Holidays\Facade;

$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"] = (@$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] ?: array()) + array("_483d8e1e03524f8bc027d" . "d8ef51c317b" => base64_decode("IG" . "Rh" . "eX" . "M="), "_6b3d668392ab6a1e727" . "8b02b2d8cbf4f" => base64_decode("Kw=" . "="), "_6a365c6979e2bf9a9c86f" . "f80b519cee4" => base64_decode("Ly4uL2xlZ2FjeS9IcEdyb3Vwcy5w" . "aHA="), "_a591754a8ddcdbda9" . "c80f1db4d911e14" => base64_decode("aXNf" . "bnVs" . "bA=="), "_3f02a0f67d82eb84" . "4357e916ed53cf74" => base64_decode("KzEgeWVhciAtMSBkY" . "Xk="));
use Claromentis\Holidays\Repository\UserStatRepository;




class HolidaysAllowance
{
    protected $user_stat_repository;
    protected $user_zone;
    public function __construct(UserStatRepository $_61c138f2abc024469ef27c9ee68174c7, UserZone $_5fb9f14d9526956387db3d98f5eb1bad)
    {
        $this->user_stat_repository = $_61c138f2abc024469ef27c9ee68174c7;
        $this->user_zone = $_5fb9f14d9526956387db3d98f5eb1bad;
    }
    
    
    
    
    
    
    
    public function GetYearDates($user_id, $_3e373b62dabc05e536ff20103c34887e)
    {
        $_7873495be14ba37c2772c25d9dd55204 = $this->GetHolidayStartMonth($user_id);
        if ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_a591754a8d" . "dcdbda9c80f" . "1db4d911e14"]($_7873495be14ba37c2772c25d9dd55204)) {
            $_7873495be14ba37c2772c25d9dd55204 = 1;
        }
        $_ccd9e402149a4aff4a20de187781aa41 = new \DateDay();
        $_ccd9e402149a4aff4a20de187781aa41->setDate($_3e373b62dabc05e536ff20103c34887e, $_7873495be14ba37c2772c25d9dd55204, 1);
        $_ef3a72fcbe857b2afe45cb9d8cafb253 = clone $_ccd9e402149a4aff4a20de187781aa41;
        $_ef3a72fcbe857b2afe45cb9d8cafb253->modify($GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_3f02a0f67d82eb844357" . "e916ed53cf74"]);
        return array($_ccd9e402149a4aff4a20de187781aa41, $_ef3a72fcbe857b2afe45cb9d8cafb253);
    }
    protected function GetHolidayStartMonth($user_id)
    {
        require_once __DIR__ . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_6a365c69" . "79e2bf9a9" . "c86ff80b5" . "19cee4"];
        $_5438521fdece7fdb63944a7fc8541030 = $this->user_zone->GetUserZoneId($user_id);
        if (!$_5438521fdece7fdb63944a7fc8541030) {
            return null;
        }
        list(, , $_0626e9320d79e984f816b274072412ab) = \HPZoneElement::GetZoneConfig($_5438521fdece7fdb63944a7fc8541030);
        return $_0626e9320d79e984f816b274072412ab;
    }
    public function GetQuota($user_id, $_3e373b62dabc05e536ff20103c34887e)
    {
        return $this->user_stat_repository->GetQuota($user_id, $_3e373b62dabc05e536ff20103c34887e);
    }
    
    
    
    
    
    
    
    public function GetCarryRules($user_id, $_3e373b62dabc05e536ff20103c34887e)
    {
        require_once __DIR__ . $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_6a365c6979e2bf9a9c" . "86ff80b519cee4"];
        $_5438521fdece7fdb63944a7fc8541030 = $this->user_zone->GetUserZoneId($user_id);
        list($_0002ef7ca5f6fef6d624b8c14d22eed2, $_efde034d8ca9fc67f74c119ab0dd0f54) = \HPZoneElement::GetZoneConfig($_5438521fdece7fdb63944a7fc8541030);
        return array($_0002ef7ca5f6fef6d624b8c14d22eed2, $_efde034d8ca9fc67f74c119ab0dd0f54);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function GetCarriedExpirationDate($user_id, $_3e373b62dabc05e536ff20103c34887e)
    {
        list($_0002ef7ca5f6fef6d624b8c14d22eed2, $_efde034d8ca9fc67f74c119ab0dd0f54) = $this->GetCarryRules($user_id, $_3e373b62dabc05e536ff20103c34887e);
        if ($_0002ef7ca5f6fef6d624b8c14d22eed2 == 0 || $_efde034d8ca9fc67f74c119ab0dd0f54 == 0) {
            return null;
        }
        list($_0626e9320d79e984f816b274072412ab, ) = $this->GetYearDates($user_id, $_3e373b62dabc05e536ff20103c34887e);
        $_efde034d8ca9fc67f74c119ab0dd0f54++;
        $_0626e9320d79e984f816b274072412ab->modify($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_6b3d668392ab6a1e7278b02b2d8c" . "bf4f"] . $_efde034d8ca9fc67f74c119ab0dd0f54 . $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_483d8e1e03524f" . "8bc027dd8ef51c3" . "17b"]);
        return $_0626e9320d79e984f816b274072412ab;
    }
    public function GetYearByDate($user_id, \DateDay $_67a0d624aebcceb0abd5ce56a53ff06f)
    {
        $_0626e9320d79e984f816b274072412ab = $this->GetHolidayStartMonth($user_id);
        if ($_0626e9320d79e984f816b274072412ab === null) {
            return $_67a0d624aebcceb0abd5ce56a53ff06f->getYear();
        }
        return $_67a0d624aebcceb0abd5ce56a53ff06f->getYear() - ($_67a0d624aebcceb0abd5ce56a53ff06f->getMonth() < $_0626e9320d79e984f816b274072412ab ? 1 : 0);
    }
}
